@@ -15,7 +15,7 @@ our @EXPORT_OK = (
 );
 our %EXPORT_TAGS = (all => \@EXPORT_OK);
 
-our $VERSION = "v6.7.2";
+our $VERSION = "v6.8.0";
 
 1;
 __END__
@@ -256,6 +256,18 @@ L<https://rxjs.dev/api/index/function/of>
     # 10, 20, 30, complete
     rx_of(10, 20, 30)->subscribe($observer);
 
+=item rx_partition
+
+L<https://rxjs.dev/api/index/function/partition>
+
+    # 1, 3, 5, 7, 9, 0, 2, 4, 6, 8, complete
+    my $source = rx_interval(1)->pipe( op_take(10) );
+    my ($o1, $o2) = rx_partition(
+        $source,
+        sub { $_[0] % 2 == 1 },
+    );
+    rx_concat($o1, $o2)->subscribe($observer);
+
 =item rx_race
 
 L<https://rxjs.dev/api/index/function/race>
